<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/**
 * Default Module file
 *
 * @package		Default module
 * @category	Modules
 * @author		Rein de Vries <info@reinos.nl>
 * @link		http://reinos.nl
 * @copyright 	Copyright (c) 2013 Reinos.nl Internet Media
 */
 
/**
 * Include the config file
 */
require_once PATH_THIRD.'segment_checker/config.php';

class Segment_checker {
		
	private $EE;
	
	// ----------------------------------------------------------------------
	
	/**
	 * Constructor
	 */
	public function __construct()
	{		
		//load default helper
		ee()->load->library(SEGMENT_CHECKER_MAP.'_lib');

		$this->keyword = ee()->TMPL->fetch_param('keyword', '');
		$this->freebie = segment_checker_helper::check_yes(ee()->TMPL->fetch_param('freebie', 'no'));
		$this->which = (int) ee()->TMPL->fetch_param('which', '1');
		if($this->freebie)
		{
			$this->segments = array_filter(explode('/', $_SERVER['REQUEST_URI']));
			$this->total_segments = count($this->segments);
			//$this->segments
		}
		else 
		{
			$this->segments = ee()->uri->segment_array();
	  		$this->total_segments = ee()->uri->total_segments();
		}
	  	

		//require the default settings
		require PATH_THIRD.SEGMENT_CHECKER_MAP.'/settings.php';

	}
	
	// ----------------------------------------
    
    /**
     * Check if a value is present in the URI
     * 
     * {exp:segment_checker:has value="test"}    
     * 
     * @return unknown_type
     */
    function has()
    {
    	//value must be filled in
    	if($this->keyword == '')
    		return false;

		$this->return_data = in_array($this->keyword, $this->segments);
		
		return $this->return_data;
    }
	
	// ----------------------------------------
    
    /**
     * Check if a value is not present in the URI 
     * 
     * {exp:segment_checker:has_not value="test"}   
     * 
     * @return unknown_type
     */
    function has_not()
    {
    	//value must be filled in
    	if($this->keyword == '')
    		return false;

		$this->return_data = !in_array($this->keyword, $this->segments);
		
		return $this->return_data;
    }
	
	// ----------------------------------------
    
    /**
     * Check if after this segment nothing is coming
     * 
     * {exp:segment_checker:empty_after value="test"}  
     * 
     * @return unknown_type
     */
    function empty_after()
    {
    	//value must be filled in
    	if($this->keyword == '')
    		return false;

		$key = array_search($this->keyword, $this->segments);
		
		//key is equal to the count, then this is the last one
		if($this->total_segments == $key)
		{
			return true;
		}
		
		return false;
    }
	
	// ----------------------------------------
    
    /**
     * Check if after this segment is coming more
     * 
     * {exp:segment_checker:not_empty_after value="test"} 
     * 
     * @return unknown_type
     */
    function not_empty_after()
    {
    	//value must be filled in
    	if($this->keyword == '')
    		return false;

		$key = array_search($this->keyword, $this->segments);
		
		//key is equal to the count, then this is the last one
		if($this->total_segments != $key)
		{
			return true;
		}
		
		return false;
    }
	
	// ----------------------------------------
    
    /**
     * Get a specific segment after a value
     * 
     * {exp:segment_checker:get_segment_after value="test" which="1"} 
     * 
     * @return unknown_type
     */
    function get_segment_after()
    {
    	//value must be filled in
    	if($this->keyword == '')
    		return false;

		$key = array_search($this->keyword, $this->segments);
		
		//key is equal to the count, then this is the last one
		if(isset($this->segments[($key+$this->which)]))
		{
			return $this->segments[($key+$this->which)];
		}
		//$this->EE->config->_global_vars['freebie_stripped_uri']
		return '';
    }
	
	// ----------------------------------------
    
    /**
     * Get a specific value before a segment value
     * 
     * {exp:segment_checker:get_segment_before value="test"} 
     * 
     * @return unknown_type
     */
    function get_segment_before()
    {
    	//value must be filled in
    	if($this->keyword == '')
    		return false;

		$key = array_search($this->keyword, $this->segments);
		
		//key is equal to the count, then this is the last one
		if(isset($this->segments[($key-$this->which)]))
		{
			return $this->segments[($key-$this->which)];
		}
		
		return '';
    }
	

	// ----------------------------------------------------------------

}


/* End of file mod.default.php */
/* Location: /system/expressionengine/third_party/default/mod.default.php */